'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Button = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _recompose = require('recompose');

var _defaultStyles = require('./defaultStyles');

var _SVGClear = require('./svg/SVGClear');

var _SVGClear2 = _interopRequireDefault(_SVGClear);

var _SVGDone = require('./svg/SVGDone');

var _SVGDone2 = _interopRequireDefault(_SVGDone);

var _SVGAdd = require('./svg/SVGAdd');

var _SVGAdd2 = _interopRequireDefault(_SVGAdd);

var _SVGRemove = require('./svg/SVGRemove');

var _SVGRemove2 = _interopRequireDefault(_SVGRemove);

var _SVGExpandLess = require('./svg/SVGExpandLess');

var _SVGExpandLess2 = _interopRequireDefault(_SVGExpandLess);

var _SVGExpandMore = require('./svg/SVGExpandMore');

var _SVGExpandMore2 = _interopRequireDefault(_SVGExpandMore);

var _helperFunctions = require('./helperFunctions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Button = function Button(_ref) {
  var _ref$type = _ref.type,
      type = _ref$type === undefined ? 'default' : _ref$type,
      children = _ref.children,
      containerRef = _ref.containerRef,
      className = _ref.className,
      style = _ref.style,
      onClick = _ref.onClick,
      _ref$settings = _ref.settings,
      settings = _ref$settings === undefined ? {} : _ref$settings,
      props = (0, _objectWithoutProperties3.default)(_ref, ['type', 'children', 'containerRef', 'className', 'style', 'onClick', 'settings']);

  var getClassName = function getClassName(_ref2) {
    var className = _ref2.className,
        isOn = _ref2.isOn,
        isDisabled = _ref2.isDisabled;

    var baseClass = 'button button--' + type;
    var baseDisabledClass = 'button--disabled button--' + type + '--disabled';
    var baseToggleClass = 'button--' + type + '--' + (isOn ? 'on' : 'off');
    if (!isDisabled) {
      if (typeof isOn !== 'undefined') {
        if (typeof className !== 'undefined') {
          return baseClass + ' ' + baseToggleClass + ' ' + className + ' ' + className + '--' + (isOn ? 'on' : 'off');
        } else {
          return baseClass + ' ' + baseToggleClass;
        }
      } else {
        if (typeof className !== 'undefined') {
          return baseClass + ' ' + className;
        } else {
          return '' + baseClass;
        }
      }
    } else {
      if (typeof className !== 'undefined') {
        return baseClass + ' ' + baseDisabledClass + ' ' + className + ' ' + className + '--disabled';
      } else {
        return baseClass + ' ' + baseDisabledClass;
      }
    }
  };

  var getButtonProps = function getButtonProps() {
    var _ref3 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var _onClick = _ref3.onClick,
        className = _ref3.className,
        style = _ref3.style,
        isOn = _ref3.isOn,
        isDisabled = _ref3.isDisabled,
        props = (0, _objectWithoutProperties3.default)(_ref3, ['onClick', 'className', 'style', 'isOn', 'isDisabled']);

    return (0, _extends3.default)({
      onClick: function onClick(e) {
        for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
          args[_key - 1] = arguments[_key];
        }

        e.stopPropagation();
        if (containerRef) {
          if (!isOn) {
            containerRef.current.style.background = settings.on;
          } else {
            containerRef.current.style.background = settings.off;
          }
        }
        _onClick && _onClick.apply(undefined, [e].concat(args));
      },
      style: style,
      onMouseOver: function onMouseOver() {
        if (containerRef) {
          if (isOn) {
            containerRef.current.style.background = settings.on;
          } else {
            containerRef.current.style.background = (0, _helperFunctions.lightenDarken)(settings.off, -30);
          }
        }
      },
      onMouseLeave: function onMouseLeave() {
        if (containerRef) {
          if (!isOn) {
            containerRef.current.style.background = settings.off;
          } else {
            containerRef.current.style.background = (0, _helperFunctions.lightenDarken)(settings.on, 30);
          }
        }
      },
      className: getClassName({ className: className, isOn: isOn, isDisabled: isDisabled })
    }, props);
  };
  var renderChildren = typeof children === 'function' ? children({ getButtonProps: getButtonProps }) : _react2.default.createElement(
    'div',
    (0, _extends3.default)({}, getButtonProps({ onClick: onClick, className: className, style: style })),
    children
  );
  var renderSwitch = function renderSwitch(type) {
    switch (type) {
      case 'increment--small--square':
        return _react2.default.createElement(_SVGAdd2.default, null);
      case 'decrement--small--square':
        return _react2.default.createElement(_SVGRemove2.default, null);
      case 'facebook--signin':
        return _react2.default.createElement(
          _react2.default.Fragment,
          null,
          _react2.default.createElement('img', { className: 'button--facebook--signin--icon', src: '/static/facebookicon.svg' }),
          _react2.default.createElement(
            'div',
            { className: 'button--facebook--signin--text' },
            renderChildren
          )
        );
      case 'google--signin':
        return _react2.default.createElement(
          _react2.default.Fragment,
          null,
          _react2.default.createElement('img', { className: 'button--google--signin--icon', src: '/static/googleicon.svg' }),
          _react2.default.createElement(
            'div',
            { className: 'button--google--signin--text' },
            renderChildren
          )
        );
      case 'withcaret--up':
        return _react2.default.createElement(
          _react2.default.Fragment,
          null,
          renderChildren,
          _react2.default.createElement(_SVGExpandLess2.default, null)
        );
      case 'withcaret--down':
        return _react2.default.createElement(
          _react2.default.Fragment,
          null,
          renderChildren,
          _react2.default.createElement(_SVGExpandMore2.default, null)
        );
      case 'yes':
        return _react2.default.createElement(
          _react2.default.Fragment,
          null,
          _react2.default.createElement(_SVGDone2.default, null),
          ' ',
          renderChildren
        );
      case 'no':
        return _react2.default.createElement(
          _react2.default.Fragment,
          null,
          _react2.default.createElement(_SVGClear2.default, null),
          ' ',
          renderChildren
        );
      default:
        return renderChildren;
    }
  };

  return _react2.default.createElement(
    _react2.default.Fragment,
    null,
    (0, _defaultStyles.getButtonStyles)().button({}),
    renderSwitch(type)
  );
};
exports.Button = Button;
Button.defaultProps = {
  settings: { on: '#c4c4c4', off: '#eeeeee', diff: 10 }
};
var enhance = (0, _recompose.compose)(_recompose.onlyUpdateForPropTypes, (0, _recompose.setPropTypes)({
  children: _propTypes2.default.node,
  type: _propTypes2.default.string,
  onClick: _propTypes2.default.func
}));

exports.default = enhance(Button);